==> php82-nextcloud-28.0.2.tgz: share/nextcloud/apps/circles/l10n/pt_BR.js <==
OC.L10N.register(
    "circles",
    {
    "Circles" : "Círculos",
    "Circles' files" : "Arquivos do círculo",
    "Select circles to filter by" : "Selecione os círculos a filtrar",
    "No circles found" : "Nenhum círculo encontrado",
    "Please select circles to filter by" : "Selecione os círculos a filtrar",
    "No files found for the selected circles" : "Nenhum arquivo encontrado nos círculos selecionados",
    "You created the circle {circle}" : "Você criou o círculo {circle}",
    "{author} created the circle {circle}" : "{author} criou o círculo {circle}",
    "You deleted {circle}" : "Você excluiu {circle}",
    "{author} deleted {circle}" : "{author} excluiu {circle}",
    "You linked {group} to {circle}" : "Você linkou {group} com {circle}",
    "{group} has been linked to {circle} by {author}" : "{group} foi linkado à {circle} por {author}",
    "You unlinked {group} from {circle}" : "você removeu o link de {group} com {circle}",
    "{group} has been unlinked from {circle} by {author}" : "{group} foi deslinkado de {circle} por {author}",
    "You changed the level of the linked group {group} in {circle} to %1$s" : "Você mudou o nível do grupo {group} linkado com {circle} para %1$s",
    "{author} changed the level of the linked group {group} in {circle} to %1$s" : "{author} mudou o nível do grupo {group} linkado com {circle} para %1$s",
    "You sent a request to link {circle} with {remote}" : "Você enviou uma solicitação para vincular {circle} a {remote}",
    "{author} sent a request to link {circle} with {remote}" : "{author} enviou uma solicitação para vincular {circle} a {remote}",
    "{remote} requested a link with {circle}" : "{remote} solicitou um link com {circle}",
    "The request to link {circle} with {remote} has been rejected" : "A solicitação para vincular {circle} a {remote} foi rejeitada",
    "The request to link {remote} with {circle} has been canceled remotely" : "A solicitação para vincular {remote} a {circle} foi cancelada remotamente",
    "The request to link {circle} with {remote} has been accepted" : "A solicitação para vincular {circle} a {remote} foi aceita",
    "You dismissed the request to link {remote} with {circle}" : "Você desconsiderou a solicitação para vincular {remote} a {circle}",
    "{author} dismissed the request to link {remote} with {circle}" : "{author} desconsiderou a solicitação para vincular {remote} a {circle}",
    "You canceled the request to link {circle} with {remote}" : "Você cancelou a solicitação para vincular {circle} a {remote}",
    "{author} canceled the request to link {circle} with {remote}" : "{author} cancelou a solicitação para vincular {circle} a {remote}",
    "You accepted the request to link {remote} with {circle}" : "Você aceitou a solicitação para vincular {remote} a {circle}",
    "{author} accepted the request to link {remote} with {circle}" : "{author} aceitou a solicitação para vincular {remote} a {circle}",
    "A link between {circle} and {remote} is now up and running" : "O link entre {circle} e {remote} está agora ativo e funcionando",
    "The link between {circle} and {remote} has been shutdown remotely" : "O link entre {circle} e {remote} foi desligado remotamente",
    "You closed the link between {circle} and {remote}" : "Você fechou o link entre {circle} e {remote}",
    "{author} closed the link between {circle} and {remote}" : "{author} fechou o link entre {circle} e {remote}",
    "You joined {circle}" : "Você juntou-se a {circle}",
    "{member} joined {circle}" : "{member} juntou-se à {circle}",
    "You accepted the invitation to join {circle}" : "Você aceitou o convite para juntar-se à {circle}",
    "{member} accepted the invitation to join {circle}" : "{member} aceitou o convite para juntar-se à {circle}",
    "You added {member} as member to {circle}" : "Você adicionou {member} como membro de {circle}",
    "You have been added as member to {circle} by {author}" : "Você foi adicionado como membro de {circle} por {author}",
    "{member} has been added as member to {circle} by {author}" : "{member} foi adicionado como membro de {circle} por {author}",
    "You added {external} to {circle}" : "Você adicionou {external} à {circle}",
    "{external} has been added to {circle} by {author}" : "{external} foi adicionado à {circle} por {author}",
    "You accepted {member}'s request to join {circle}" : "Você aceitou a solicitação de {member} para juntar-se à {circle}",
    "Your request to join {circle} has been accepted by {author}" : "Sua solicitação para juntar-se à {circle} foi aceita por {author}",
    "{member}'s request to join {circle} has been accepted by {author}" : "A solicitação de {member} para juntar-se à {circle} foi aceita por {author}",
    "You left {circle}" : "Você saiu de {circle}",
    "{member} left {circle}" : "{member} deixou {circle}",
    "You declined the invitation to join {circle}" : "Você recusou o convite para juntar-se a {circle}",
    "{member} declined an invitation to join {circle}" : "{member} recusou o convite para juntar-se a {circle}",
    "You cancelled your request to join {circle}" : "Você cancelou o convite para juntar-se a {circle}",
    "{member} cancelled his request to join {circle}" : "{member} cancelou o convite para juntar-se a {circle}",
    "You removed {member} from {circle}" : "Você excluiu {member} de {circle}",
    "You have been removed from {circle} by {author}" : "Você foi removido de {circle} por {author}",
    "{member} has been removed from {circle} by {author}" : "{member} foi removido de {circle} por {author}",
    "You removed {external} from {circle}" : "Você removeu {external} de {circle}",
    "{external} has been removed from {circle} by {author}" : "{external} foi removido de {circle} por {author}",
    "You cancelled {member}'s invitation to join {circle}" : "Você cancelou o convite de {member} para juntar-se a {circle}",
    "Your invitation to join {circle} has been cancelled by {author}" : "Seu convite para juntar-se a {circle} foi cancelado por {author}",
    "{author} cancelled {member}'s invitation to join {circle}" : "{author} cancelou o convite de {member} para juntar-se a {circle}",
    "You dismissed {member}'s request to join {circle}" : "Você descartou a solicitação de {member} para juntar-se à {circle}",
    "Your request to join {circle} has been dismissed by {author}" : "Sua solicitação para juntar-se à {circle} foi descartada por {author}",
    "{member}'s request to join {circle} has been dismissed by {author}" : "A solicitação de {member} para juntar-se à {circle} foi descartada por {author}",
    "You invited {member} to join {circle}" : "Você convidou {member} a juntar-se à {circle}",
    "You have been invited to join {circle} by {author}" : "Você foi convidado a juntar-se à {circle} por {author}",
    "{member} has been invited to join {circle} by {author}" : "{member} foi convidado a juntar-se à {circle} por {author}",
    "You changed {member}'s level in {circle} to %1$s" : "Você mudou o nível de {member} em {circle} para %1$s",
    "{author} changed your level in {circle} to %1$s" : "{author} mudou seu nível em {circle} para %1$s",
    "{author} changed {member}'s level in {circle} to %1$s" : "{author} mudou o nível de {member} em {circle} para %1$s",
    "You sent a request to join {circle}" : "Você solicitou juntar-se à {circle}",
    "{member} sent a request to join {circle}" : "{member} solicitou juntar-se à {circle}",
    "You are the new owner of {circle}" : "Você é o novo proprietário de {circle}",
    "{member} is the new owner of {circle}" : "{member} é o novo proprietário de {circle}",
    "On events happening in a <strong>Circle</strong> of which you are a member" : "Em eventos acontecendo em um <strong>Círculo</strong> do qual você é membro",
    "Any important event in a <strong>Circle</strong> you are moderating" : "Qualquer evento importante em um <strong>Círculo</strong> que você está moderando",
    "On global events happening in any <strong>Circle</strong>" : "Em eventos globais acontecendo em qualquer <strong>Círculo</strong>",
    "Shared to Circles" : "Compartilhar com Círculos",
    "Single" : "Único",
    "Personal" : "Pessoal",
    "System" : "Sistema",
    "Visible" : "Visível",
    "Open" : "Abrir",
    "Invite" : "Convidar",
    "Join Request" : "Pedido de adesão",
    "Friends" : "Amigos",
    "Password Protected" : "Protegido por senha",
    "No Owner" : "Sem proprietário",
    "Hidden" : "Oculto",
    "Backend" : "Processo Interno",
    "Local" : "Local",
    "Root" : "Raiz",
    "Circle Invite" : "Convite do Círculo",
    "Federated" : "Federado",
    "Mount point" : "Ponto de montagem",
    "Nextcloud Account" : "Conta Nextcloud",
    "Nextcloud Group" : "Grupo Nextcloud",
    "Email Address" : "Endereço de e-mail",
    "Contact" : "Contato",
    "Circle" : "Círculo",
    "Nextcloud App" : "Aplicativo Nextcloud",
    "Member" : "Membro",
    "Moderator" : "Moderador",
    "Admin" : "Administrador",
    "Owner" : "Proprietário",
    "%s shared »%s« with you." : "%s compartilhou »%s« com você.",
    "%s shared »%s« with \"%s\"." : "%s compartilhou »%s« com \"%s\".",
    "%s on %s" : "%s em %s",
    "%1$s shared »%2$s« with you.\nYou should have already received a separate email with a link to access it.\n" : "%1$s compartilhou »%2$s« com você.\nVocê já deve ter recebido um e-mail separado com um link para acessar.\n",
    "%1$s shared »%2$s« with you. You should have already received a separate email with a link to access it." : "%1$s compartilhou »%2$s« com você. Você já deve ter recebido um e-mail separado com um link para acessá-lo.",
    "Password to access »%1$s« shared to you by %2$s" : "Senha para acessar »%1$s« compartilhado com você por %2$s",
    "Password to access »%s«" : "Senha para acessar »%s«",
    "It is protected with the following password:" : "Está protegido com a seguinte senha:",
    "%1$s via %2$s" : "%1$s via %2$s",
    "Click the button below to open it." : "Clique no botão abaixo para abri-lo.",
    "Open »%s«" : "Abrir »%s«",
    "%1$s shared multiple files with you.\nYou should have already received a separate email with a link to access them.\n" : "%1$s compartilhou vários arquivos com você.\nVocê já deve ter recebido um e-mail separado com um link para acessá-los.\n",
    "%1$s shared multiple files with you. You should have already received a separate email with a link to access them." : "%1$s compartilhou vários arquivos com você. Você já deve ter recebido um e-mail separado com um link para acessá-los.",
    "Password to access files shared to you by %1$s" : "Senha para acessar os arquivos compartilhados com você por %1$s",
    "Password to access files" : "Senha para acessar arquivos",
    "%s shared multiple files with \"%s\"." : "%s compartilhou vários arquivos com \"%s\".",
    "%s shared multiple files with you." : "%s compartilhou vários arquivos com você. ",
    "Boot up" : "Inicializar",
    "Nextcloud Initialization" : "Nextcloud Initialization",
    "Circles App Initialization" : "Inicialização do aplicativo Círculos",
    "Fresh installation status" : "Novo status de instalação",
    "Building Local Database" : "Construindo banco de dados local",
    "Testing Basic Circle Creation" : "Teste básico de criação de círculo",
    "Adding local users and moderators" : "Adicionando usuários locais e moderadores",
    "Circle not found" : "Círculo não encontrado",
    "Circle not found " : "Círculo não encontrado",
    "This member does not exist" : "Este membro não existe",
    "This account is already a member of the circle" : "Esta conta já é membro do círculo",
    "Federated link not found" : "Link federado não encontrado",
    "This feature is not available for personal circles" : "Este recurso não está disponível para círculos pessoais",
    "The circle is not federated" : "O círculo não é federado",
    "You cannot join this circle" : "Você não pode juntar-se ao círculo",
    "This member is not a moderator" : "Este membro não é moderador",
    "Insufficient privileges" : "Permissões insuficientes",
    "This member is the owner of the circle" : "Este membro é o proprietário do círculo",
    "Level cannot be changed for this type of member" : "O nível não pode ser mudado para este tipo de usuário",
    "You are already a member of this circle" : "Você já é membro deste círculo",
    "You have been blocked from this circle" : "Você foi bloqueado neste círculo",
    "The account is already a member of this circle" : "A conta já é membro deste círculo",
    "The account has already been invited into this circle" : "A conta já foi convidada para este círculo",
    "%s (Circle owned by %s)" : "%s (Círculo de propriedade de %s)",
    "You are now a member of the Circle \"%2$s\"" : "Agora você é membro do Círculo \"%2$s\"",
    "You have been invited by %1$s into the Circle \"%2$s\"" : "Você foi convidado por %1$s para o Círculo \"%2$s\"",
    "%1$s sent a request to be a member of the Circle \"%2$s\"" : "%1$s solicitou ser membro do Círculo \"%2$s\"",
    "Accept" : "Aceitar",
    "Refuse" : "Recusar",
    "Leave the circle" : "Sair do círculo",
    "%s" : "%s",
    "Personal Circle" : "Círculo Pessoal",
    "%s owned by %s" : "%s propriedade de %s",
    "You need a specify a type of circle" : "Você precisa especificar um tipo de círculo",
    "A circle with that name exists" : "Um círculo com este nome já existe",
    "This member is not the owner of the circle" : "Este membro não é o proprietário do círculo",
    "This member is not an admin of the circle" : "Este usuário não é um administrador do círculo",
    "Group contains too many members" : "O grupo contém muitos membros",
    "This group does not exist" : "Este grupo não existe",
    "This group is already linked to the circle" : "Este grupo já está vinculado ao círculo",
    "You cannot edit level in a personal circle" : "Você não pode editar o nível em um círculo pessoal",
    "Group cannot be set as owner of a circle" : "Grupo não pode ser definido como proprietário de um círculo",
    "now" : "agora",
    "This account does not exist" : "Essa conta não existe",
    "Email format is not valid" : "O formato do e-mail é inválido",
    "This contact is not available" : "Este contato não está disponível",
    "You have no permission to create a new circle" : "Você não tem permissão para criar um novo círculo",
    "%s shared a file with \"%s\"." : "%s compartilhou um arquivo com \"%s\".",
    "%s shared a file with you." : "%s compartilhou um arquivo com você.",
    "%1$s shared some content with you.\nYou should have already received a separate email with a link to access it.\n" : "%1$s compartilhou algum conteúdo com você.\nVocê já deve ter recebido um e-mail separado com um link para acessá-lo.\n",
    "%1$s shared some content with you. You should have already received a separate email with a link to access it." : "%1$s compartilhou algum conteúdo com você. Você já deve ter recebido um e-mail separado com um link para acessá-lo.",
    "Password to access content shared with you by %1$s" : "Senha para acessar o conteúdo compartilhado com você por %1$s",
    "Password to access content" : "Senha para acessar o conteúdo",
    "This item is already shared with this circle" : "Este item já está compartilhado com este círculo",
    "Bring cloud-users closer together." : "Reúna os usuários da nuvem.",
    "Circles allows people to create their own groups of people/colleagues/friends.\nThose groups of people (or \"circles\") can then be used by any other app for sharing purpose." : "Os círculos permitem que as pessoas criem seus próprios grupos de pessoas/colegas/amigos.\nEsses grupos de pessoas (ou \"círculos\") podem ser usados por qualquer outro aplicativo para fins de compartilhamento.",
    "No files in here" : "Nenhum arquivo aqui",
    "No entries found in this folder" : "Sem entradas nesta pasta",
    "Name" : "Nome",
    "Size" : "Tamanho",
    "Modified" : "Modificado",
    "Initialisation Nextcloud" : "Inicialização do Nextcloud",
    "Initialisation Circles App" : "Inicialização do aplicativo Círculos"
},
"nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");

==> php82-nextcloud-29.0.7.tgz: share/nextcloud/apps/circles/l10n/pt_BR.js <==
OC.L10N.register(
    "circles",
    {
    "Teams" : "Equipes",
    "You created the team {circle}" : "Você criou a equipe {circle}",
    "{author} created the team {circle}" : "{author} criou a equipe {circle}",
    "You deleted {circle}" : "Você excluiu {circle}",
    "{author} deleted {circle}" : "{author} excluiu {circle}",
    "You made {member} join {circle}" : "Você fez com que {member} se juntasse a {circle}",
    "{author} made {member} join {circle}" : "{author} fez com que {member} se juntasse a {circle}",
    "You added team {member} as member to {circle}" : "Você adicionou a equipe {member} como membro de {circle}",
    "{author} added team {member} as member to {circle}" : "{autor} Equipe adicionada {membro} como membro da {circle}",
    "You made {member} leave {circle}" : "Você fez {member} sair de {circle}",
    "{author} made {member} leave {circle}" : "{author} fez com que {membro} saísse de {circle}",
    "You removed {member} from {circle}" : "Você excluiu {member} de {circle}",
    "{author} removed {member} from {circle}" : "{author} removido {membro} de {circle}",
    "You joined {circle}" : "Você juntou-se a {circle}",
    "{member} joined {circle}" : "{member} juntou-se à {circle}",
    "You accepted the invitation to join {circle}" : "Você aceitou o convite para juntar-se à {circle}",
    "{member} accepted the invitation to join {circle}" : "{member} aceitou o convite para juntar-se à {circle}",
    "You added {member} as member to {circle}" : "Você adicionou {member} como membro de {circle}",
    "You have been added as member to {circle} by {author}" : "Você foi adicionado como membro de {circle} por {author}",
    "{member} has been added as member to {circle} by {author}" : "{member} foi adicionado como membro de {circle} por {author}",
    "You added {external} to {circle}" : "Você adicionou {external} à {circle}",
    "{external} has been added to {circle} by {author}" : "{external} foi adicionado à {circle} por {author}",
    "You accepted {member}'s request to join {circle}" : "Você aceitou a solicitação de {member} para juntar-se à {circle}",
    "Your request to join {circle} has been accepted by {author}" : "Sua solicitação para juntar-se à {circle} foi aceita por {author}",
    "{member}'s request to join {circle} has been accepted by {author}" : "A solicitação de {member} para juntar-se à {circle} foi aceita por {author}",
    "You left {circle}" : "Você saiu de {circle}",
    "{member} left {circle}" : "{member} deixou {circle}",
    "You declined the invitation to join {circle}" : "Você recusou o convite para juntar-se a {circle}",
    "{member} declined an invitation to join {circle}" : "{member} recusou o convite para juntar-se a {circle}",
    "You cancelled your request to join {circle}" : "Você cancelou o convite para juntar-se a {circle}",
    "{member} cancelled a request to join {circle}" : "{member} cancelou uma solicitação para ingressar em {circle}",
    "You have been removed from {circle} by {author}" : "Você foi removido de {circle} por {author}",
    "{member} has been removed from {circle} by {author}" : "{member} foi removido de {circle} por {author}",
    "You removed {external} from {circle}" : "Você removeu {external} de {circle}",
    "{external} has been removed from {circle} by {author}" : "{external} foi removido de {circle} por {author}",
    "You cancelled {member}'s invitation to join {circle}" : "Você cancelou o convite de {member} para juntar-se a {circle}",
    "Your invitation to join {circle} has been cancelled by {author}" : "Seu convite para juntar-se a {circle} foi cancelado por {author}",
    "{author} cancelled {member}'s invitation to join {circle}" : "{author} cancelou o convite de {member} para juntar-se a {circle}",
    "You dismissed {member}'s request to join {circle}" : "Você descartou a solicitação de {member} para juntar-se à {circle}",
    "Your request to join {circle} has been dismissed by {author}" : "Sua solicitação para juntar-se à {circle} foi descartada por {author}",
    "{member}'s request to join {circle} has been dismissed by {author}" : "A solicitação de {member} para juntar-se à {circle} foi descartada por {author}",
    "You invited {member} to join {circle}" : "Você convidou {member} a juntar-se à {circle}",
    "You have been invited to join {circle} by {author}" : "Você foi convidado a juntar-se à {circle} por {author}",
    "{member} has been invited to join {circle} by {author}" : "{member} foi convidado a juntar-se à {circle} por {author}",
    "You changed {member}'s level in {circle} to %1$s" : "Você mudou o nível de {member} em {circle} para %1$s",
    "{author} changed your level in {circle} to %1$s" : "{author} mudou seu nível em {circle} para %1$s",
    "{author} changed {member}'s level in {circle} to %1$s" : "{author} mudou o nível de {member} em {circle} para %1$s",
    "You sent a request to join {circle}" : "Você solicitou juntar-se à {circle}",
    "{member} sent a request to join {circle}" : "{member} solicitou juntar-se à {circle}",
    "You are the new owner of {circle}" : "Você é o novo proprietário de {circle}",
    "{member} is the new owner of {circle}" : "{member} é o novo proprietário de {circle}",
    "On events happening in a <strong>team</strong> of which you are a member" : "Em eventos que acontecem em um <strong>equipe</strong> do qual você é membro",
    "Any important event in a <strong>team</strong> you are moderating" : "Qualquer evento importante em uma <strong>equipe</strong> que você está moderando",
    "On global events happening in any <strong>team</strong>" : "Em eventos globais que acontecem em qualquer <strong>equipe</strong>",
    "Shared to Circles" : "Compartilhar com Círculos",
    "Single" : "Único",
    "Personal" : "Pessoal",
    "System" : "Sistema",
    "Visible" : "Visível",
    "Open" : "Abrir",
    "Invite" : "Convidar",
    "Join request" : "Solicitação de adesão",
    "Friends" : "Amigos",
    "Password protected" : "Protegido por senha",
    "No Owner" : "Sem proprietário",
    "Hidden" : "Oculto",
    "Backend" : "Processo Interno",
    "Local" : "Local",
    "Root" : "Raiz",
    "Team invite" : "Convite da equipe",
    "Federated" : "Federado",
    "Mount point" : "Ponto de montagem",
    "Nextcloud Account" : "Conta Nextcloud",
    "Nextcloud Group" : "Grupo Nextcloud",
    "Email address" : "Endereço de e-mail",
    "Contact" : "Contato",
    "Circle" : "Círculo",
    "Nextcloud App" : "Aplicativo Nextcloud",
    "Member" : "Membro",
    "Moderator" : "Moderador",
    "Admin" : "Administrador",
    "Owner" : "Proprietário",
    "%s shared »%s« with you." : "%s compartilhou »%s« com você.",
    "%s shared »%s« with \"%s\"." : "%s compartilhou »%s« com \"%s\".",
    "%s on %s" : "%s em %s",
    "%1$s shared »%2$s« with you.\nYou should have already received a separate email with a link to access it.\n" : "%1$s compartilhou »%2$s« com você.\nVocê já deve ter recebido um e-mail separado com um link para acessar.\n",
    "%1$s shared »%2$s« with you. You should have already received a separate email with a link to access it." : "%1$s compartilhou »%2$s« com você. Você já deve ter recebido um e-mail separado com um link para acessá-lo.",
    "Password to access »%1$s« shared to you by %2$s" : "Senha para acessar »%1$s« compartilhado com você por %2$s",
    "Password to access »%s«" : "Senha para acessar »%s«",
    "It is protected with the following password:" : "Está protegido com a seguinte senha:",
    "%1$s via %2$s" : "%1$s via %2$s",
    "Click the button below to open it." : "Clique no botão abaixo para abri-lo.",
    "Open »%s«" : "Abrir »%s«",
    "%1$s shared multiple files with you.\nYou should have already received a separate email with a link to access them.\n" : "%1$s compartilhou vários arquivos com você.\nVocê já deve ter recebido um e-mail separado com um link para acessá-los.\n",
    "%1$s shared multiple files with you. You should have already received a separate email with a link to access them." : "%1$s compartilhou vários arquivos com você. Você já deve ter recebido um e-mail separado com um link para acessá-los.",
    "Password to access files shared to you by %1$s" : "Senha para acessar os arquivos compartilhados com você por %1$s",
    "Password to access files" : "Senha para acessar arquivos",
    "%s shared multiple files with \"%s\"." : "%s compartilhou vários arquivos com \"%s\".",
    "%s shared multiple files with you." : "%s compartilhou vários arquivos com você. ",
    "Boot up" : "Inicializar",
    "Nextcloud Initialization" : "Nextcloud Initialization",
    "Circles App Initialization" : "Inicialização do aplicativo Círculos",
    "Fresh installation status" : "Novo status de instalação",
    "Building Local Database" : "Construindo banco de dados local",
    "Testing Basic Circle Creation" : "Teste básico de criação de círculo",
    "Adding local users and moderators" : "Adicionando usuários locais e moderadores",
    "Show all teams" : "Mostrar todas as equipes",
    "Create a new team" : "Crie uma nova equipe",
    "Files" : "Arquivos",
    "This feature is not available for personal circles" : "Este recurso não está disponível para círculos pessoais",
    "The team is not federated" : "A equipe não é federada",
    "You cannot join this team" : "Você não pode entrar nesta equipe",
    "This member is not a moderator" : "Este membro não é moderador",
    "Insufficient privileges" : "Permissões insuficientes",
    "This member does not exist" : "Este membro não existe",
    "This member is the owner of the team" : "Este membro é o proprietário da equipe",
    "Level cannot be changed for this type of member" : "O nível não pode ser mudado para este tipo de usuário",
    "You are already a member of this circle" : "Você já é membro deste círculo",
    "You have been blocked from this circle" : "Você foi bloqueado neste círculo",
    "The account is already a member of this circle" : "A conta já é membro deste círculo",
    "The account has already been invited into this circle" : "A conta já foi convidada para este círculo",
    "%s (Team owned by %s)" : "%s(Equipe de propriedade de %s)",
    "You are now a member of the Circle \"%2$s\"" : "Agora você é membro do Círculo \"%2$s\"",
    "You have been invited by %1$s into the Circle \"%2$s\"" : "Você foi convidado por %1$s para o Círculo \"%2$s\"",
    "%1$s sent a request to be a member of the Circle \"%2$s\"" : "%1$s solicitou ser membro do Círculo \"%2$s\"",
    "Accept" : "Aceitar",
    "Refuse" : "Recusar",
    "Leave the circle" : "Sair do círculo",
    "%s" : "%s",
    "Personal team" : "Equipe pessoal",
    "%s owned by %s" : "%s propriedade de %s",
    "You have no permission to create a new team" : "Você não tem permissão para criar uma nova equipe",
    "%s shared a file with \"%s\"." : "%s compartilhou um arquivo com \"%s\".",
    "%s shared a file with you." : "%s compartilhou um arquivo com você.",
    "%1$s shared some content with you.\nYou should have already received a separate email with a link to access it.\n" : "%1$s compartilhou algum conteúdo com você.\nVocê já deve ter recebido um e-mail separado com um link para acessá-lo.\n",
    "%1$s shared some content with you. You should have already received a separate email with a link to access it." : "%1$s compartilhou algum conteúdo com você. Você já deve ter recebido um e-mail separado com um link para acessá-lo.",
    "Password to access content shared with you by %1$s" : "Senha para acessar o conteúdo compartilhado com você por %1$s",
    "Password to access content" : "Senha para acessar o conteúdo",
    "This item is already shared with this team" : "Este item já está compartilhado com esta equipe",
    "Bring cloud-users closer together." : "Reúna os usuários da nuvem.",
    "Teams allows people to create their own groups of people/colleagues/friends.\nThose groups of people can then be used by any other app for sharing purpose." : "O Teams permite que as pessoas criem seus próprios grupos de pessoas/colegas/amigos. \nEsses grupos de pessoas podem então ser usados ​​por qualquer outro aplicativo para fins de compartilhamento.",
    "No files in here" : "Nenhum arquivo aqui",
    "No entries found in this folder" : "Sem entradas nesta pasta",
    "Name" : "Nome",
    "Size" : "Tamanho",
    "Modified" : "Modificado",
    "Circles" : "Círculos",
    "Circles' files" : "Arquivos do círculo",
    "Select circles to filter by" : "Selecione os círculos a filtrar",
    "No circles found" : "Nenhum círculo encontrado",
    "Please select circles to filter by" : "Selecione os círculos a filtrar",
    "No files found for the selected circles" : "Nenhum arquivo encontrado nos círculos selecionados",
    "You created the circle {circle}" : "Você criou o círculo {circle}",
    "{author} created the circle {circle}" : "{author} criou o círculo {circle}",
    "You added circle {member} as member to {circle}" : "Você adicionou o círculo {member} como membro de {circle}",
    "{author} added circle {member} has been added as member to {circle}" : "{author} adicionou a equipe {member} como membro de {circle}",
    "You removed {member} leave {circle}" : "Você removeu {member}, saiu de {circle}",
    "On events happening in a <strong>Circle</strong> of which you are a member" : "Em eventos acontecendo em um <strong>Círculo</strong> do qual você é membro",
    "Any important event in a <strong>Circle</strong> you are moderating" : "Qualquer evento importante em um <strong>Círculo</strong> que você está moderando",
    "On global events happening in any <strong>Circle</strong>" : "Em eventos globais acontecendo em qualquer <strong>Círculo</strong>",
    "Join Request" : "Pedido de adesão",
    "Password Protected" : "Protegido por senha",
    "Circle Invite" : "Convite do Círculo",
    "Email Address" : "Endereço de e-mail",
    "Circle not found" : "Círculo não encontrado",
    "Circle not found " : "Círculo não encontrado",
    "This account is already a member of the circle" : "Esta conta já é membro do círculo",
    "Federated link not found" : "Link federado não encontrado",
    "The circle is not federated" : "O círculo não é federado",
    "You cannot join this circle" : "Você não pode juntar-se ao círculo",
    "This member is the owner of the circle" : "Este membro é o proprietário do círculo",
    "%s (Circle owned by %s)" : "%s (Círculo de propriedade de %s)",
    "Personal Circle" : "Círculo Pessoal",
    "You need a specify a type of circle" : "Você precisa especificar um tipo de círculo",
    "A circle with that name exists" : "Um círculo com este nome já existe",
    "This member is not the owner of the circle" : "Este membro não é o proprietário do círculo",
    "This member is not an admin of the circle" : "Este usuário não é um administrador do círculo",
    "Group contains too many members" : "O grupo contém muitos membros",
    "This group does not exist" : "Este grupo não existe",
    "This group is already linked to the circle" : "Este grupo já está vinculado ao círculo",
    "You cannot edit level in a personal circle" : "Você não pode editar o nível em um círculo pessoal",
    "Group cannot be set as owner of a circle" : "Grupo não pode ser definido como proprietário de um círculo",
    "now" : "agora",
    "This account does not exist" : "Essa conta não existe",
    "Email format is not valid" : "O formato do e-mail é inválido",
    "This contact is not available" : "Este contato não está disponível",
    "You have no permission to create a new circle" : "Você não tem permissão para criar um novo círculo",
    "This item is already shared with this circle" : "Este item já está compartilhado com este círculo",
    "Circles allows people to create their own groups of people/colleagues/friends.\nThose groups of people (or \"circles\") can then be used by any other app for sharing purpose." : "Os círculos permitem que as pessoas criem seus próprios grupos de pessoas/colegas/amigos.\nEsses grupos de pessoas (ou \"círculos\") podem ser usados por qualquer outro aplicativo para fins de compartilhamento.",
    "Teams' files" : "Arquivos das equipes",
    "Select team to filter by" : "Selecione a equipe para filtrar",
    "No teams found" : "Nenhuma equipe encontrada",
    "Please select teams to filter by" : "Selecione equipes para filtrar",
    "No files found for the selected teams" : "Nenhum arquivo encontrado para as equipes selecionadas",
    "{author} added team {member} has been added as member to {circle}" : "{author} adicionou a equipe {member} como membro de {circle}"
},
"nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
